@@ -23,9 +23,11 @@ def render_to_stl_file(root, filename):
         scad_render_to_file(root,
                             Path(filename).with_suffix(".stl.scad"))
 
+    cmd = config.openscad_stl_command.format(scadfile=scad_file, stlfile=filename)
+
+    import shlex
     import subprocess
-    args = ["openscad", "-o", filename, scad_file]
-    subprocess.check_call(args,
+    subprocess.check_call(shlex.split(cmd),
                           stdout=subprocess.PIPE,
                           stderr=subprocess.DEVNULL)
 
@@ -38,7 +40,7 @@ def scad_render(root, file_header = ''):
     #call extensions pre_render
     from .extension_manager import default_extension_manager
     extensions_header_str = default_extension_manager.call_pre_render(root)
-    extensions_header_str += "\n" if extensions_header_str else ''
+    extensions_header_str += "\n\n" if extensions_header_str else ''
 
     #wrap the extensions around the root node
     root = default_extension_manager.wrap_root_node(root)
@@ -75,7 +77,7 @@ def _write_to_file(out_string, filename=None, outdir=''):
 
     outfile_path = outpath / Path(outfile)
 
-    outfile_path.write_text(out_string)
+    outfile_path.write_text(out_string, encoding="utf-8")
     return outfile_path.absolute().as_posix()
 
 def get_include_string():
