@@ -1,6 +1,8 @@
 #! /usr/bin/env python
 
-from solid2 import *
+from solid2 import cube, text, translate, union, scad_render_to_file, scad_inline, \
+                   CustomizerDropdownVariable, CustomizerSliderVariable, \
+                   scad_for, scad_range
 
 #register all the custom variables you want to use
 objects = CustomizerDropdownVariable("objects", 4, [2, 4, 6])
@@ -11,20 +13,10 @@ customizedText = CustomizerDropdownVariable("text", "customize me!",
                                             ["customize me!", "Thank you!"])
 
 #use scad_inline to use them
-scene = union()
-scene += scad_inline("""
-                    for (i = [1:objects]){
-                        translate([2*i*side,0,0]){
-                            cube(side);
-                        }
-                    }
-                    """)
+scene = scad_for(scad_range(1, objects), lambda i: cube(side).left(2*i*side))
 
-scene += translate(cube_pos) (
-            cube(cube_size * 2))
-
-scene += translate([0, -20, 0]) (
-            text(str(customizedText)))
+scene += cube(cube_size * 2).translate(cube_pos)
+scene += text(customizedText).back(20) #type: ignore
 
 scad_render_to_file(scene)
 
