@@ -4,7 +4,7 @@ from pathlib import Path as _Path
 
 from .bosl2_base import Bosl2Base as _Bosl2Base
 
-_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/shapes3d.scad'}", use_not_include=False)
+_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/shapes3d.scad'}", False)
 
 class cube(_Bosl2Base):
     def __init__(self, size=None, center=None, anchor=None, spin=None, orient=None, **kwargs):
@@ -39,8 +39,12 @@ class cylinder(_Bosl2Base):
        super().__init__("cylinder", {"h" : h, "r1" : r1, "r2" : r2, "center" : center, "r" : r, "d" : d, "d1" : d1, "d2" : d2, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class cyl(_Bosl2Base):
-    def __init__(self, h=None, r=None, center=None, l=None, r1=None, r2=None, d=None, d1=None, d2=None, length=None, height=None, chamfer=None, chamfer1=None, chamfer2=None, chamfang=None, chamfang1=None, chamfang2=None, rounding=None, rounding1=None, rounding2=None, circum=None, realign=None, shift=None, from_end=None, from_end1=None, from_end2=None, texture=None, tex_size=None, tex_counts=None, tex_inset=None, tex_rot=None, tex_scale=None, tex_samples=None, tex_taper=None, tex_style=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("cyl", {"h" : h, "r" : r, "center" : center, "l" : l, "r1" : r1, "r2" : r2, "d" : d, "d1" : d1, "d2" : d2, "length" : length, "height" : height, "chamfer" : chamfer, "chamfer1" : chamfer1, "chamfer2" : chamfer2, "chamfang" : chamfang, "chamfang1" : chamfang1, "chamfang2" : chamfang2, "rounding" : rounding, "rounding1" : rounding1, "rounding2" : rounding2, "circum" : circum, "realign" : realign, "shift" : shift, "from_end" : from_end, "from_end1" : from_end1, "from_end2" : from_end2, "texture" : texture, "tex_size" : tex_size, "tex_counts" : tex_counts, "tex_inset" : tex_inset, "tex_rot" : tex_rot, "tex_scale" : tex_scale, "tex_samples" : tex_samples, "tex_taper" : tex_taper, "tex_style" : tex_style, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, h=None, r=None, center=None, l=None, r1=None, r2=None, d=None, d1=None, d2=None, length=None, height=None, chamfer=None, chamfer1=None, chamfer2=None, chamfang=None, chamfang1=None, chamfang2=None, rounding=None, rounding1=None, rounding2=None, circum=None, realign=None, shift=None, teardrop=None, from_end=None, from_end1=None, from_end2=None, texture=None, tex_size=None, tex_counts=None, tex_inset=None, tex_rot=None, tex_scale=None, tex_samples=None, tex_taper=None, tex_style=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("cyl", {"h" : h, "r" : r, "center" : center, "l" : l, "r1" : r1, "r2" : r2, "d" : d, "d1" : d1, "d2" : d2, "length" : length, "height" : height, "chamfer" : chamfer, "chamfer1" : chamfer1, "chamfer2" : chamfer2, "chamfang" : chamfang, "chamfang1" : chamfang1, "chamfang2" : chamfang2, "rounding" : rounding, "rounding1" : rounding1, "rounding2" : rounding2, "circum" : circum, "realign" : realign, "shift" : shift, "teardrop" : teardrop, "from_end" : from_end, "from_end1" : from_end1, "from_end2" : from_end2, "texture" : texture, "tex_size" : tex_size, "tex_counts" : tex_counts, "tex_inset" : tex_inset, "tex_rot" : tex_rot, "tex_scale" : tex_scale, "tex_samples" : tex_samples, "tex_taper" : tex_taper, "tex_style" : tex_style, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+
+class _teardrop_corner(_Bosl2Base):
+    def __init__(self, r=None, corner=None, ang=None, **kwargs):
+       super().__init__("_teardrop_corner", {"r" : r, "corner" : corner, "ang" : ang, **kwargs})
 
 class xcyl(_Bosl2Base):
     def __init__(self, h=None, r=None, d=None, r1=None, r2=None, d1=None, d2=None, l=None, chamfer=None, chamfer1=None, chamfer2=None, chamfang=None, chamfang1=None, chamfang2=None, rounding=None, rounding1=None, rounding2=None, circum=None, realign=None, from_end=None, length=None, height=None, anchor=None, spin=None, orient=None, **kwargs):
@@ -131,8 +135,8 @@ class cylinder(_Bosl2Base):
        super().__init__("cylinder", {"h" : h, "r1" : r1, "r2" : r2, "center" : center, "r" : r, "d" : d, "d1" : d1, "d2" : d2, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class cyl(_Bosl2Base):
-    def __init__(self, h=None, r=None, center=None, l=None, r1=None, r2=None, d=None, d1=None, d2=None, chamfer=None, chamfer1=None, chamfer2=None, chamfang=None, chamfang1=None, chamfang2=None, rounding=None, rounding1=None, rounding2=None, circum=None, realign=None, shift=None, from_end=None, from_end1=None, from_end2=None, texture=None, tex_size=None, tex_counts=None, tex_inset=None, tex_rot=None, tex_scale=None, tex_samples=None, length=None, height=None, tex_taper=None, tex_style=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("cyl", {"h" : h, "r" : r, "center" : center, "l" : l, "r1" : r1, "r2" : r2, "d" : d, "d1" : d1, "d2" : d2, "chamfer" : chamfer, "chamfer1" : chamfer1, "chamfer2" : chamfer2, "chamfang" : chamfang, "chamfang1" : chamfang1, "chamfang2" : chamfang2, "rounding" : rounding, "rounding1" : rounding1, "rounding2" : rounding2, "circum" : circum, "realign" : realign, "shift" : shift, "from_end" : from_end, "from_end1" : from_end1, "from_end2" : from_end2, "texture" : texture, "tex_size" : tex_size, "tex_counts" : tex_counts, "tex_inset" : tex_inset, "tex_rot" : tex_rot, "tex_scale" : tex_scale, "tex_samples" : tex_samples, "length" : length, "height" : height, "tex_taper" : tex_taper, "tex_style" : tex_style, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, h=None, r=None, center=None, l=None, r1=None, r2=None, d=None, d1=None, d2=None, chamfer=None, chamfer1=None, chamfer2=None, chamfang=None, chamfang1=None, chamfang2=None, rounding=None, rounding1=None, rounding2=None, circum=None, realign=None, shift=None, teardrop=None, from_end=None, from_end1=None, from_end2=None, texture=None, tex_size=None, tex_counts=None, tex_inset=None, tex_rot=None, tex_scale=None, tex_samples=None, length=None, height=None, tex_taper=None, tex_style=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("cyl", {"h" : h, "r" : r, "center" : center, "l" : l, "r1" : r1, "r2" : r2, "d" : d, "d1" : d1, "d2" : d2, "chamfer" : chamfer, "chamfer1" : chamfer1, "chamfer2" : chamfer2, "chamfang" : chamfang, "chamfang1" : chamfang1, "chamfang2" : chamfang2, "rounding" : rounding, "rounding1" : rounding1, "rounding2" : rounding2, "circum" : circum, "realign" : realign, "shift" : shift, "teardrop" : teardrop, "from_end" : from_end, "from_end1" : from_end1, "from_end2" : from_end2, "texture" : texture, "tex_size" : tex_size, "tex_counts" : tex_counts, "tex_inset" : tex_inset, "tex_rot" : tex_rot, "tex_scale" : tex_scale, "tex_samples" : tex_samples, "length" : length, "height" : height, "tex_taper" : tex_taper, "tex_style" : tex_style, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class xcyl(_Bosl2Base):
     def __init__(self, h=None, r=None, d=None, r1=None, r2=None, d1=None, d2=None, l=None, chamfer=None, chamfer1=None, chamfer2=None, chamfang=None, chamfang1=None, chamfang2=None, rounding=None, rounding1=None, rounding2=None, circum=None, realign=None, from_end=None, length=None, height=None, anchor=None, spin=None, orient=None, **kwargs):
