@@ -4,7 +4,7 @@ from pathlib import Path as _Path
 
 from .bosl2_base import Bosl2Base as _Bosl2Base
 
-_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/threading.scad'}", use_not_include=False)
+_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/threading.scad'}", False)
 
 class threaded_rod(_Bosl2Base):
     def __init__(self, d=None, l=None, pitch=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, starts=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
@@ -15,12 +15,12 @@ class threaded_nut(_Bosl2Base):
        super().__init__("threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "starts" : starts, "shape" : shape, "left_handed" : left_handed, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "id1" : id1, "id2" : id2, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "ibevel" : ibevel, "bevang" : bevang, "thickness" : thickness, "height" : height, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class trapezoidal_threaded_rod(_Bosl2Base):
-    def __init__(self, d=None, l=None, pitch=None, thread_angle=None, thread_depth=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, starts=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("trapezoidal_threaded_rod", {"d" : d, "l" : l, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "left_handed" : left_handed, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "starts" : starts, "internal" : internal, "d1" : d1, "d2" : d2, "length" : length, "h" : h, "height" : height, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, d=None, l=None, pitch=None, thread_angle=None, thread_depth=None, flank_angle=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, starts=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("trapezoidal_threaded_rod", {"d" : d, "l" : l, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "flank_angle" : flank_angle, "left_handed" : left_handed, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "starts" : starts, "internal" : internal, "d1" : d1, "d2" : d2, "length" : length, "h" : h, "height" : height, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class trapezoidal_threaded_nut(_Bosl2Base):
-    def __init__(self, nutwidth=None, id=None, h=None, pitch=None, thread_angle=None, thread_depth=None, shape=None, left_handed=None, starts=None, bevel=None, bevel1=None, bevel2=None, bevang=None, ibevel1=None, ibevel2=None, ibevel=None, thickness=None, height=None, id1=None, id2=None, length=None, l=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("trapezoidal_threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "shape" : shape, "left_handed" : left_handed, "starts" : starts, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "bevang" : bevang, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "ibevel" : ibevel, "thickness" : thickness, "height" : height, "id1" : id1, "id2" : id2, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, nutwidth=None, id=None, h=None, pitch=None, thread_angle=None, thread_depth=None, shape=None, flank_angle=None, left_handed=None, starts=None, bevel=None, bevel1=None, bevel2=None, bevang=None, ibevel1=None, ibevel2=None, ibevel=None, thickness=None, height=None, id1=None, id2=None, length=None, l=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("trapezoidal_threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "shape" : shape, "flank_angle" : flank_angle, "left_handed" : left_handed, "starts" : starts, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "bevang" : bevang, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "ibevel" : ibevel, "thickness" : thickness, "height" : height, "id1" : id1, "id2" : id2, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class acme_threaded_rod(_Bosl2Base):
     def __init__(self, d=None, l=None, tpi=None, pitch=None, starts=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
@@ -63,8 +63,8 @@ class generic_threaded_nut(_Bosl2Base):
        super().__init__("generic_threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "profile" : profile, "shape" : shape, "left_handed" : left_handed, "starts" : starts, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "bevang" : bevang, "ibevel" : ibevel, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "id1" : id1, "id2" : id2, "height" : height, "thickness" : thickness, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class thread_helix(_Bosl2Base):
-    def __init__(self, d=None, pitch=None, thread_depth=None, flank_angle=None, turns=None, profile=None, starts=None, left_handed=None, internal=None, d1=None, d2=None, taper=None, taper1=None, taper2=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("thread_helix", {"d" : d, "pitch" : pitch, "thread_depth" : thread_depth, "flank_angle" : flank_angle, "turns" : turns, "profile" : profile, "starts" : starts, "left_handed" : left_handed, "internal" : internal, "d1" : d1, "d2" : d2, "taper" : taper, "taper1" : taper1, "taper2" : taper2, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, d=None, pitch=None, thread_depth=None, flank_angle=None, turns=None, profile=None, starts=None, left_handed=None, internal=None, d1=None, d2=None, thread_angle=None, lead_in_shape=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, lead_in_sample=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("thread_helix", {"d" : d, "pitch" : pitch, "thread_depth" : thread_depth, "flank_angle" : flank_angle, "turns" : turns, "profile" : profile, "starts" : starts, "left_handed" : left_handed, "internal" : internal, "d1" : d1, "d2" : d2, "thread_angle" : thread_angle, "lead_in_shape" : lead_in_shape, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "lead_in_sample" : lead_in_sample, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class threaded_rod(_Bosl2Base):
     def __init__(self, d=None, l=None, pitch=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, starts=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
@@ -75,12 +75,12 @@ class threaded_nut(_Bosl2Base):
        super().__init__("threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "starts" : starts, "shape" : shape, "left_handed" : left_handed, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "id1" : id1, "id2" : id2, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "ibevel" : ibevel, "bevang" : bevang, "thickness" : thickness, "height" : height, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class trapezoidal_threaded_rod(_Bosl2Base):
-    def __init__(self, d=None, l=None, pitch=None, thread_angle=None, thread_depth=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, starts=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("trapezoidal_threaded_rod", {"d" : d, "l" : l, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "left_handed" : left_handed, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "starts" : starts, "internal" : internal, "d1" : d1, "d2" : d2, "length" : length, "h" : h, "height" : height, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, d=None, l=None, pitch=None, thread_angle=None, thread_depth=None, flank_angle=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, starts=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("trapezoidal_threaded_rod", {"d" : d, "l" : l, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "flank_angle" : flank_angle, "left_handed" : left_handed, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "starts" : starts, "internal" : internal, "d1" : d1, "d2" : d2, "length" : length, "h" : h, "height" : height, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class trapezoidal_threaded_nut(_Bosl2Base):
-    def __init__(self, nutwidth=None, id=None, h=None, pitch=None, thread_angle=None, thread_depth=None, shape=None, left_handed=None, starts=None, bevel=None, bevel1=None, bevel2=None, bevang=None, ibevel1=None, ibevel2=None, ibevel=None, thickness=None, height=None, id1=None, id2=None, length=None, l=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("trapezoidal_threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "shape" : shape, "left_handed" : left_handed, "starts" : starts, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "bevang" : bevang, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "ibevel" : ibevel, "thickness" : thickness, "height" : height, "id1" : id1, "id2" : id2, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, nutwidth=None, id=None, h=None, pitch=None, thread_angle=None, thread_depth=None, shape=None, flank_angle=None, left_handed=None, starts=None, bevel=None, bevel1=None, bevel2=None, bevang=None, ibevel1=None, ibevel2=None, ibevel=None, thickness=None, height=None, id1=None, id2=None, length=None, l=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("trapezoidal_threaded_nut", {"nutwidth" : nutwidth, "id" : id, "h" : h, "pitch" : pitch, "thread_angle" : thread_angle, "thread_depth" : thread_depth, "shape" : shape, "flank_angle" : flank_angle, "left_handed" : left_handed, "starts" : starts, "bevel" : bevel, "bevel1" : bevel1, "bevel2" : bevel2, "bevang" : bevang, "ibevel1" : ibevel1, "ibevel2" : ibevel2, "ibevel" : ibevel, "thickness" : thickness, "height" : height, "id1" : id1, "id2" : id2, "length" : length, "l" : l, "blunt_start" : blunt_start, "blunt_start1" : blunt_start1, "blunt_start2" : blunt_start2, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "end_len" : end_len, "end_len1" : end_len1, "end_len2" : end_len2, "lead_in_shape" : lead_in_shape, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
 class acme_threaded_rod(_Bosl2Base):
     def __init__(self, d=None, l=None, tpi=None, pitch=None, starts=None, left_handed=None, bevel=None, bevel1=None, bevel2=None, internal=None, d1=None, d2=None, length=None, h=None, height=None, blunt_start=None, blunt_start1=None, blunt_start2=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, end_len=None, end_len1=None, end_len2=None, lead_in_shape=None, anchor=None, spin=None, orient=None, **kwargs):
@@ -127,6 +127,6 @@ class _nutshape(_Bosl2Base):
        super().__init__("_nutshape", {"nutwidth" : nutwidth, "h" : h, "shape" : shape, "bevel1" : bevel1, "bevel2" : bevel2, **kwargs})
 
 class thread_helix(_Bosl2Base):
-    def __init__(self, d=None, pitch=None, thread_depth=None, flank_angle=None, turns=None, profile=None, starts=None, left_handed=None, internal=None, d1=None, d2=None, lead_in_shape=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, lead_in_sample=None, anchor=None, spin=None, orient=None, **kwargs):
-       super().__init__("thread_helix", {"d" : d, "pitch" : pitch, "thread_depth" : thread_depth, "flank_angle" : flank_angle, "turns" : turns, "profile" : profile, "starts" : starts, "left_handed" : left_handed, "internal" : internal, "d1" : d1, "d2" : d2, "lead_in_shape" : lead_in_shape, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "lead_in_sample" : lead_in_sample, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
+    def __init__(self, d=None, pitch=None, thread_depth=None, flank_angle=None, turns=None, profile=None, starts=None, left_handed=None, internal=None, d1=None, d2=None, thread_angle=None, lead_in_shape=None, lead_in=None, lead_in1=None, lead_in2=None, lead_in_ang=None, lead_in_ang1=None, lead_in_ang2=None, lead_in_sample=None, anchor=None, spin=None, orient=None, **kwargs):
+       super().__init__("thread_helix", {"d" : d, "pitch" : pitch, "thread_depth" : thread_depth, "flank_angle" : flank_angle, "turns" : turns, "profile" : profile, "starts" : starts, "left_handed" : left_handed, "internal" : internal, "d1" : d1, "d2" : d2, "thread_angle" : thread_angle, "lead_in_shape" : lead_in_shape, "lead_in" : lead_in, "lead_in1" : lead_in1, "lead_in2" : lead_in2, "lead_in_ang" : lead_in_ang, "lead_in_ang1" : lead_in_ang1, "lead_in_ang2" : lead_in_ang2, "lead_in_sample" : lead_in_sample, "anchor" : anchor, "spin" : spin, "orient" : orient, **kwargs})
 
